#
# spec file for package python-stomper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-stomper
Version:        0.4.3
Release:        4.2
Summary:        Transport neutral client implementation of the STOMP protocol
License:        Apache-2.0
URL:            https://code.google.com/p/stomper
Source0:        https://files.pythonhosted.org/packages/source/s/stomper/stomper-%{version}.tar.gz
Patch0:         remove-future-requirement.patch
Patch1:         fix-test-assertion-methods.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This is a python client implementation of the STOMP protocol.

The client is attempting to be transport layer neutral. This module provides
functions to create and parse STOMP messages in a programatic fashion. The
messages can be easily generated and parsed, however its up to the user to do
the sending and receiving.

%prep
%autosetup -p1 -n stomper-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest lib/stomper/tests/*

%files %{python_files}
%doc README.rst lib/stomper/examples
%license LICENSE
%{python_sitelib}/stomper
%{python_sitelib}/stomper-%{version}.dist-info

%changelog
* Wed Mar 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch fix-test-assertion-methods.patch, use non-removed assertion
  methods.
* Fri Sep  8 2023 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject and autosetup macros.
- Stop using greedy globs in %%files.
- Add patch remove-future-requirement.patch, remove future requirement.
* Wed Jun  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- replace nose with pytest
* Thu Apr 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.4.3
  * Added missing attribution to contributors section and messed up
    0.4.2 release to new pypi.
  * Thanks to https://github.com/pgajdos for contributing a fix to
    include the license in the distribution.
- removed LICENSE (now it is included).
* Tue Mar 26 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid repetition of project name or self in summary (rpmlint).
* Tue Mar 26 2019 pgajdos@suse.com
- version update to 0.4.1
  * python3 support
  * utf-8 encoding under python3
- build also python3 variant
- drop SLE11 support
- run fdupes
- include LICENSE
* Wed May 13 2015 benoit.monin@gmx.fr
- update to version 0.3.0:
  * This release makes STOMP v1.1 the default protocol. To stick
    with STOMP v1.0 you can continue to use stomper v0.2.9 or
    change the import in your code to:
    import stomper.stomp_10 as stomper
  * Note: Any fixes to STOMP v1.0 will only be applied to
    version >= 0.3.
- additional changes from version 0.2.9:
  * Thanks to Ralph Bean for contributing the new protocol 1.1
    support:
    https://github.com/oisinmulvihill/stomper/issues/6
    https://github.com/oisinmulvihill/stomper/pull/7
- additional changes from version 0.2.8:
  * Thanks to Daniele Varrazzo for contributing the fixes:
    + https://github.com/oisinmulvihill/stomper/pull/4
    Fixed newline prepended to messages without transaction id
    + https://github.com/oisinmulvihill/stomper/pull/5
    Fixed reST syntax. Extension changed to allow github to
    render it properly. Also changed the source url in the readme
- rename README.md to README.rst: changed upstream
* Sun Nov 17 2013 p.drouand@gmail.com
- Update to version 0.2.7
  + add a MANIFEST.in which makes sure README.md is present. Without
    this pip install fails: https://github.com/oisinmulvihill/stomper/issues/3.
- Changes from version 0.2.6
  + correct many spelling mistakes throughout the code base.
  + make the README.md the main
- Changes from 0.2.5
  + removes the extra line ending which can cause problems.
- README has been renamed in README.md; change it in %%doc
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Mar 14 2012 saschpe@suse.de
- Simplified macro usage, ran spec-cleaner
* Thu Sep 22 2011 saschpe@suse.de
- Require python-uuid for SLE_10 and below.
- Use python-nose for unittests to fix SLE build
* Thu Sep 22 2011 saschpe@suse.de
- Fixed license to Apache-2.0
* Thu Sep 22 2011 saschpe@suse.de
- Update to version 0.2.4:
  * Fixing the problem whereby uuid would be installed on python2.5+.
- Changes from version 0.2.3:
  * Fixed issue #9 with the example code. All messages are sent and received correctly.
- Spec file cleanup:
  * Added proper changes file and spec file license header
  * Run testsuite
* Thu Apr  9 2009 silas@sewell.ch
- Remove Python version dependency
* Sun Mar 29 2009 silas@sewell.ch
- Fix dependencies
* Thu Mar 26 2009 silas@sewell.ch
- Update package name to conform to Fedora naming standards
- Change define to global
* Fri Mar 20 2009 silas@sewell.ch
- Update upstream package to remove hidden files
* Thu Mar  5 2009 silas@sewell.ch
- Manually remove hidden files
* Wed Dec 17 2008 silas@sewell.ch
- Initial package
